###############
Users
###############

The following universities, research institutes, companies and non-governmental organisations are known to have either used PyPSA in the past, or to continue to use PyPSA. This list is necessarily incomplete, since we cannot track who uses PyPSA and we only find out who our users are when they contact the main developers of PyPSA.

Research publications that cite the `PyPSA research paper <https://doi.org/10.5334/jors.188>`_ can be found on `Google Scholar <https://scholar.google.com/scholar?oi=bibs&hl=en&cites=11241966939032736670&as_sdt=5>`_.

The PyPSA user meetings give further insight into the use of PyPSA in the energy sector.

.. raw:: html

    <iframe width="560" height="315" src="https://www.youtube.com/embed/43DK6_kFfN0" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

Find the 1st PyPSA user meeting in 10/2022 `here <https://www.youtube.com/embed/fmwDxNpSMM4>`_.

.. _academic-mentions:

Universities and Research Institutes
====================================

* `Technische Universität Berlin <https://www.ensys.tu-berlin.de/>`_ (TUB, where PyPSA development continues): multiple research papers, for example: `doi.org:10.1016/j.eneco.2021.105354 <https://doi.org/10.1016/j.eneco.2021.105354>`_, `doi:10.1016/j.energy.2021.120784 <https://doi.org/10.1016/j.energy.2021.120784>`_, `doi:10.1016/j.apenergy.2022.118859 <https://doi.org/10.1016/j.apenergy.2022.118859>`_

* `Karlsruhe Institute of Technology <https://www.kit.edu/>`_ (KIT, where PyPSA development continues): multiple research papers, for example: `doi:10.1016/j.energy.2018.06.222 <https://doi.org/10.1016/j.energy.2018.06.222)>`_, `doi:10.1109/EEM.2019.8916411 <https://www.doi.org/10.1109/EEM.2019.8916411>`_, `doi:10.1016/j.esr.2018.08.012 <https://doi.org/10.1016/j.esr.2018.08.012>`_, `doi:10.1016/j.epsr.2020.106690 <https://doi.org/10.1016/j.epsr.2020.106690>`_, `doi:10.1145/3396851.3397688 <https://doi.org/10.1145/3396851.3397688>`_, `doi:10.1016/j.apenergy.2021.116726 <https://doi.org/10.1016/j.apenergy.2021.116726>`_, `doi:10.1186/s42162-022-00187-7 <https://doi.org/10.1186/s42162-022-00187-7>`_

* `Aarhus University <https://www.au.dk/>`_ in Denmark: multiple research papers, for example: `doi:10.1016/j.apenergy.2019.02.009 <https://doi.org/10.1016/j.apenergy.2019.02.009>`_, `doi:10.1016/j.apenergy.2018.12.016 <https://doi.org/10.1016/j.apenergy.2018.12.016>`_, `doi:10.1002/pip.3198 <https://doi.org/10.1002/pip.3198>`_, `doi:10.1016/j.enconman.2019.111977 <https://doi.org/10.1016/j.enconman.2019.111977>`_, `doi:10.1038/s41467-020-20015-4 <https://doi.org/10.1038/s41467-020-20015-4>`_, `doi:10.1016/j.joule.2022.04.016 <https://doi.org/10.1016/j.joule.2022.04.016>`_

* `Frankfurt Institute of Advanced Studies <https://fias.science/>`_ (FIAS, where PyPSA was initially developed): multiple research papers, for example: `doi:10.1016/j.energy.2017.06.004 <https://doi.org/10.1016/j.energy.2017.06.004>`_, `doi:10.1109/EEM.2017.7982024 <https://doi.org/10.1109/EEM.2017.7982024>`_, `doi:10.1016/j.energy.2018.08.070 <https://doi.org/10.1016/j.energy.2018.08.070>`_, `doi:10.1016/j.apenergy.2018.09.084 <https://doi.org/10.1016/j.apenergy.2018.09.084>`_, `doi:10.1016/j.epsr.2017.12.034 <https://doi.org/10.1016/j.epsr.2017.12.034>`_

* `Stanford University <https://www.stanford.edu/>`_ in the United States: research paper: `doi:10.2139/ssrn.5029120 <https://dx.doi.org/10.2139/ssrn.5029120>`_

* `TU Delft <https://www.tudelft.nl/>`_ in the Netherlands: multiple research papers: `doi:10.1016/j.eneco.2018.04.037 <https://doi.org/10.1016/j.eneco.2018.04.037>`_, `doi:10.1016/j.energy.2017.02.111 <https://doi.org/10.1016/j.energy.2017.02.111>`_

* `Joint Research Centre (JRC) <https://joint-research-centre.ec.europa.eu/index_en>`_ of the `European Commission <https://ec.europa.eu/info/index_en>`_ converted METIS/PRIMES scenarios for the `Fit for 55 package to PyPSA networks <https://zenodo.org/record/7065568#.YygkDKRByMo>`_ in 2022 and used PyPSA for further research: `doi:10.3390/en15124233 <https://doi.org/10.3390/en15124233>`_ in 2022. In 2023, JRC used PyPSA for the study `"MODECO – Modelling study on the role of energy communities in the energy transition" <https://publications.jrc.ec.europa.eu/repository/handle/JRC132896>`_ and in 2024 for the study `"Redispatch and Congestion Management" <https://publications.jrc.ec.europa.eu/repository/handle/JRC137685>`_

* `Chalmers University <https://www.chalmers.se/>`_ in Sweden: research paper: `doi.org:10.1016/j.apenergy.2022.120016 <https://doi.org/10.1016/j.apenergy.2022.120016>`_

* `UiT The Arctic University of Norway (UiT) <https://uit.no/>`_ and the `University of Oslo (UiO) <https://www.uio.no/>`_ use PyPSA for studying near-optimal spaces in renewable electricity system planning: `doi.org:10.1016/j.eneco.2022.106496 <https://doi.org/10.1016/j.eneco.2022.106496>`_.

* `PyPSA-meets-Earth initiative <https://pypsa-meets-earth.github.io/>`_ including `University of Edinburgh <https://www.ed.ac.uk/>`_, `University of Pisa <https://www.unipi.it/index.php/english/>`_ and `others <https://pypsa-earth.readthedocs.io/en/latest/project_structure_and_credits.html>`_, uses PyPSA for joint research. Example publications: `PyPSA-Earth. A new global open energy system optimization model demonstrated in Africa <https://doi.org/10.1016/j.apenergy.2023.121096>`_

* `Reiner Lemoine Institute <https://reiner-lemoine-institut.de/>`_, `Center for Sustainable Energy Systems <https://www.znes-flensburg.de/>`_ in Flensburg, Germany: consortial project `open-Ego <https://github.com/openego>`_, multiple publications: `doi:10.3390/en12112091 <https://doi.org/10.3390/en12112091>`_, `doi:10.1088/1742-6596/977/1/012007 <https://doi.org/10.1088/1742-6596/977/1/012007>`_, `doi:10.1016/j.apenergy.2021.116936 <https://doi.org/10.1016/j.apenergy.2021.116936>`_

* `Kyoto University <https://www.kyoto-u.ac.jp/en>`_ in Japan: uses PyPSA to model several high PV penetration scenarios in Kyushu, the southernmost region of Japan, where PV capacity has been rapidly growing since 2012 and PV curtailment started in 2018: `doi:10.3390/en14092389 <https://doi.org/10.3390/en14092389>`_,  `doi:10.3390/en14154496 <https://doi.org/10.3390/en14154496>`_

* `University of Geneva <https://www.unige.ch/>`_ in Switzerland: research paper `doi:10.1038/s41467-020-18812-y <https://doi.org/10.1038/s41467-020-18812-y>`_

* `DLR Institute of Networked Energy Systems <https://www.dlr.de/ve/desktopdefault.aspx/tabid-12472/21440_read-49440/>`_ in Oldenburg, Germany: research paper `doi:10.1016/j.apenergy.2020.114523 <https://doi.org/10.1016/j.apenergy.2020.114523>`_ and a `dataset publication <https://doi.org/10.1038/s41597-023-01992-9>`_ for the Brazilian power system.

* `University of Oxford <https://www.ox.ac.uk/>`_ in `study on green ammonia imports <https://iopscience.iop.org/article/10.1088/2753-3751/ad785d>`_ as a supplement to long-duration energy storage in the UK and with the `University of Sevilla <https://www.us.es/>`_ in a `study on the role of regionally resolved heat pump demand <https://doi.org/10.1016/j.apenergy.2023.122331>`_ in power system design.

* `Council for Scientific and Industrial Research <https://www.csir.co.za/>`_ (CSIR) in South Africa: research publication `arXiv:1710.11199 <https://arxiv.org/abs/1710.11199>`_

* `Energiewirtschaftliches Institut zu Köln <https://www.ewi.uni-koeln.de/de/>`_ (EWI): research publication `Working Paper, No 17/09 <https://www.ewi.research-scenarios.de/cms/wp-content/uploads/2017/09/EWI_WP_17-09_Build_Wind_Capacities_at_Windy_Locations.pdf>`_

* `Fraunhofer Institute for Solar Energy Systems <https://www.ise.fraunhofer.de/>`_ (ISE): uses PyPSA for grid modelling, research paper: `doi:/10.1016/j.epsr.2020.106349 <https://doi.org/10.1016/j.epsr.2020.106349>`_

* `Fraunhofer Institute for Energy Infrastructures and Geothermal Systems <https://www.ieg.fraunhofer.de/>`_ (IEG): uses PyPSA-Eur-Sec for infrastructure analysis in Europe, e.g. in the `European Hydrogen Infrastructure Planning report <https://www.wasserstoff-leitprojekte.de/lw_resource/datapool/systemfiles/elements/files/148FFEF003673B67E0637E695E8625E5/live/document/20240321_European_Hydrogen_Infrastructure_Planning.pdf>`_ on European hydrogen infrastructure planning.

* `Fraunhofer-Institut für Energiewirtschaft und Energiesystemtechnik <https://www.iee.fraunhofer.de/>`_ (IEE): used PyPSA for an investigation of power-to-X in South Africa together with Stellenbosch University in `this report <20240430_PtX-Allocation-Study_Stakeholder-Workshop-Interim-Results.pdf>`_.

* `EIA University <https://www.eia.edu.co/>`_ in Medellin, Columbia: uses PyPSA for modelling the Columbian power system in  a joint research project with South American transmission company `ISA <http://www.isa.co/>`_

* `Dublin City University <https://dcu.ie/>`_ and the `SFI Insight Centre for Data Analytics <https://www.insight-centre.org/>`_: use PyPSA for the `OESM project <https://sites.google.com/a/dcu.ie/dcuecrn/projects/oesm-ie>`_ modelling the Irish energy system

* `INATECH <https://www.inatech.uni-freiburg.de/en>`_ at `University of Freiburg <https://uni-freiburg.de/>`_

* `Institut für Energiesystemtechnik <https://www.ines.hs-offenburg.de/>`_  at `Hochschule Offenburg <https://www.hs-offenburg.de/>`_

* `Forschungszentrum Jülich <https://www.fz-juelich.de/>`_ (FZJ) for network calculations

* `Forschungsstelle für Energiewirtschaft (FfE) <https://www.ffe.de/>`_ uses PyPSA for their `HyPTraDe <https://www.ffe.de/tools/hyptrade-global-hydrogen-modellkette/>`__ global hydrogen model chain.

* `Forschungsstelle für Energienetze und Energiespeicher (FENES) <https://www.fenes.net/>`_ at `Ostbayerische Technische Hochschule Regensburg <https://www.oth-regensburg.de/>`_

* `TH Köln <https://www.th-koeln.de/>`_ used PyPSA for `a study on the role of renewables, storage and sector-coupling flexibilities in Germany at varying carbon-dioxide emission levels <https://doi.org/10.3390/su141610379>`_.

* `Sustainable Energy Research Group (SERG) <https://www.canterbury.ac.nz/research/about-uc-research/research-groups-and-centres/sustainable-energy-research-group>`_ at `University of Canterbury <https://www.canterbury.ac.nz/>`_ uses PyPSA for energy transition in New Zealand

* `The University of Edinburgh <https://www.eng.ed.ac.uk/research/institutes/ies>`_: introduced PyPSA-GB: An open-source model of Great Britain's power system for simulating future energy scenarios (Energy Strategy Reviews, May 2024) `doi.org/10.1016/j.esr.2024.101375 <https://doi.org/10.1016/j.esr.2024.101375>`_

* `Energy Innovation Lab <https://energyinnovation.korea.ac.kr/>`_ at `Korea University <https://www.korea.ac.kr/sites/ko/index.do>`_ uses PyPSA-Earth to support development of long-term energy strategy

* `South and South-East Asia Multidisciplinary Applied Research Network on Transforming Societies of Global South (SMARTS) <https://ait.ac.th/centre/smartscenter/>`_ at `Asian Institute of Technology <https://ait.ac.th/>`_  and `Department of Electrical and Electronic Engineering at International University of Business Agriculture and Technology (IUBAT), Dhaka <https://eee.iubat.edu/>`_ developed an adaptation of PyPSA-Earth, called PyPSA-BD to support the energy transition in Bangladesh `<https://doi.org/10.1016/j.ref.2024.100655>`_

* `RISE Research Institutes of Sweden AB <https://www.ri.se/>`_ (RISE) for energy systems research in `RESILIENT project <https://resilient-project.github.io/>`_ and more.

Companies, Governmental and Non-Governmental Organisations
==========================================================

* `International Energy Agency (IEA) <https://www.iea.org/>`_ uses PyPSA within their `Global Energy
  and Climate Model
  <https://www.iea.org/reports/global-energy-and-climate-model>`_. A 2024 report `Managing the Seasonal Variability of Electricity Demand and Supply <https://www.iea.org/reports/managing-the-seasonal-variability-of-electricity-demand-and-supply>`_ used PyPSA to explore how seasonal variations in both demand and supply affect electricity system operations in various world regions in 2050.

* `Joint Research Centre (JRC) <https://joint-research-centre.ec.europa.eu/index_en>`_ of the `European Commission <https://ec.europa.eu/info/index_en>`_ in various studies (see :ref:`academic-mentions` for details).

* `TransnetBW <https://www.transnetbw.de/>`_ (the electricity transmission system operator in southwest Germany), `ONTRAS <https://www.ontras.com/>`_, (the gas transmission system operator in eastern Germany) and `d-fine <https://www.d-fine.com/>`_ (the consultancy firm): used PyPSA-Eur-Sec for a study in 2020 of the grid requirements in 2050 with a 90% reduction of carbon dioxide emissions in electricity, buildings and transport, see `Stromnetz 2050 <https://www.transnetbw.de/de/stromnetz2050/>`_, for an article in a 2021 issue of Energiewirtschaftliche Tagesfragen `Die Rolle von Wasserstoff in einem klimaneutralen europäischen Energiesystem – eine modellbasierte Analyse bis 2050 <https://www.d-fine.com/fileadmin/user_upload/Wasserstoff_et_0102-2021.pdf>`_, and for their 2022 study `Energy System 2050 - Towards a decarbonised Europe <https://www.energysystem2050.net/>`_.

* `ENTSO-E (European Network of Transmission System Operators for Electricity) <https://www.entsoe.eu/>`_ launched in collaboration with `Open Energy Transition <https://openenergytransition.org/>`_ a research and innovation project to develop a complementary open-source tool in PyPSA for `Scenario Building and Cost-Benefit Analysis within the TYNDP process <https://www.linkedin.com/posts/entso-e_energytransition-opensource-innovation-activity-7293296246813851649-2ynL>`_.

* `The EU Agency for the Cooperation of Energy Regulators (ACER) <https://www.acer.europa.eu/>`_ is building a PyPSA solution for the `EU-wide flexibility assessment platform <https://www.acer.europa.eu/sites/default/files/documents/en/The_agency/Organisation/Expert_Groups/EG_Flexibility/Flexibility_EG_Open_Letter_2025.pdf>`_.

* `Open Energy Transition <https://openenergytransition.org/>`_, a non-profit software company and environmental think tank: uses, develops and provides commercial support and training for PyPSA. List of projects: `https://openenergytransition.org/projects.html <https://openenergytransition.org/projects.html>`_

* `RAND Europe <https://www.rand.org/randeurope.html>`_ used PyPSA in a 2024 report `The use of AI for improving energy security <https://www.rand.org/pubs/research_reports/RRA2907-2.html>`_ to explore the extent to which different AI applications can improve energy security in Europe.

* `The Energy and Resources Institute <https://www.teriin.org/>`_ (TERI) in New Delhi, India: Used PyPSA for several studies. In 2020 for a government-supported study of the Indian power system in 2030, see `Renewable Power Pathways Report <https://www.teriin.org/sites/default/files/2020-07/Renewable-Power-Pathways-Report.pdf>`_, in 2021 for a study on `A Model-Based Assessment of Variable Renewable Grid Integration Costs in India <https://www.teriin.org/sites/default/files/2021-02/A_Modal-Based_Assessment_Report_0.pdf>`_ and in 2024 for a study on `India’s Electricity Transition Pathways to 2050: Scenarios and Insights <https://teriin.org/sites/default/files/2024-02/Power_Sector_2050_Report.pdf>`_

* `Ember <https://ember-climate.org/>`_, a UK-based climate NGO: published a study in September 2022 on a `gas phase-out in the UK by 2030 <https://ember-climate.org/insights/research/uk-gas-power-phase-out/>`_ based on their open model `PyPSA-UK <https://github.com/ember-climate/pypsa-uk>`_

* `Agora Energiewende <https://www.agora-energiewende.de/>`_, a think tank and policy institute in Germany: uses PyPSA for energy system integration studies, see for example this study from 2020: `Minimizing the cost of integrating wind and solar power in Japan <https://www.agora-energiewende.de/en/publications/minimizing-the-cost-of-integrating-wind-and-solar-power-in-japan/>`_

* `Austrian Power Grid (APG) <https://www.apg.at/>`_, the Austrian TSO, uses PyPSA for its system vision of the Austrian energy system up to 2050, as shown in `this talk <https://www.tugraz.at/fileadmin/user_upload/tugrazExternal/738639ca-39a0-4129-b0f0-38b384c12b57/files/pr/Session_A3/132_PR_Spindler.pdf>`_ and `this project description <https://www.apg.at/projekte/zusammen-2040/>`_.

* `Centre for Net Zero <https://www.centrefornetzero.org/>`_, a research unit
  founded by `Octopus Energy <https://octopus.energy>`_, used PyPSA in a `report
  <https://www.centrefornetzero.org/work/whole-system-modelling-of-future-energy-scenarios-domestic-gb-demand-flexibility/>`_
  to investigate the role of demand flexibility in future UK energy systems.

* `The Rocky Mountain Institute <https://rmi.org/>`_ (RMI), a non-profit organization in the United States focused on a zero-carbon future, used PyPSA for analysing the levelised cost of hydrogen in different parts of the world in a study from 2021: `Fueling the Transition: Accelerating Cost-Competitive Green Hydrogen <https://rmi.org/insight/fueling-the-transition-accelerating-cost-competitive-green-hydrogen/>`_

* `Climate Analytics <https://climateanalytics.org/>`_, a non-profit climate science and policy institute, uses PyPSA for energy system studies, see for example a study on `Employment opportunities from a coal-to-renewables transition in South Korea <https://climateanalytics.org/publications/2021/employment-opportunities-from-a-coal-to-renewables-transition-in-south-korea/>`_ and a `study on the Philippines <https://climateanalytics.org/publications/a-15c-future-is-possible-getting-fossil-fuels-out-of-the-philippine-power-sector>`_.

* `Instrat <https://instrat.pl/en/>`_, a think-tank focused on public policy in Poland, built PyPSA-PL and published reports in 2021 including `What's next after coal? RES potential in Poland <http://instrat.pl/wp-content/uploads/2021/06/Instrat-What-next-after-coal-v.1.2.pdf>`_ and `Achieving the goal: Coal phase-out in the Polish power sector <https://instrat.pl/en/coal-phase-out/>`_

* `GIZ <https://www.giz.de/en/html/index.html>`_, the  German Agency for
  International Cooperation (Deutsche Gesellschaft für Internationale
  Zusammenarbeit) published and supported several studies based on PyPSA for the
  `integration of renewables into the Vietnamese power system
  <http://gizenergy.org.vn/media/app/media/Research%20Cooperation%20Project%20Fact%20Sheet_final.pdf>`_,
  `power sector analysis for Thailand <https://static.agora-energiewende.de/fileadmin/Partnerpublikationen/2021/CASE_Beyond_Net_Zero_Empowering_Climate_Mitigation/Towards_a_collective_vision_of_Thai_energy_transition_full_report.pdf>`_ within the CASE programme, `the
  future of the Indonesian power system <https://energynautics.com/en/pypsa/>`_ within the "1000 Islands"
  programme, and the `Brazilian electricity system <https://www.energy-proceedings.org/wp-content/uploads/2022/03/Y.Deng_PyPSA-Brazil_ICAE2021_final_revised.pdf>`_

* The `Canada Energy Regulator (CER) <https://www.cer-rec.gc.ca/en/>`_, an agency of the Government of Canada, used PyPSA for its `Canada's Energy Future 2023 report <https://www.cer-rec.gc.ca/en/data-analysis/canada-energy-future/2023/appendix-3/>`_

* `Meridian Economics <https://meridianeconomics.co.za/>`_, a consultancy based in South Africa, uses PyPSA ecosystem tools and PyPSA-Earth for South Africa. Studies published in June 2022 were on `load shedding in 2021 <https://meridianeconomics.co.za/wp-content/uploads/2022/06/Resolving-Load-Shedding-Part-A-2021-analysis-01.pdf>`_ and `a plan to resolve load shedding <https://meridianeconomics.co.za/wp-content/uploads/2022/06/Resolving-Load-Shedding-Part-B-The-Game-Plan-01.pdf>`_

* `Energynautics GmbH <https://energynautics.com/>`_, a grid integration consultancy in Germany: used PyPSA for a study of decentral electricity and heat integration in power grids in a study for the Rhineland-Palatinate state government in 2021: `Pilotprojekt Dezentralisierung: Stärkere Dezentralisierung des bundesdeutschen Strom-Wärme-Systems: Rechtliche und organisatorische Rahmenbedingungen sowie infrastrukturelle Folgen <https://mkuem.rlp.de/fileadmin/mulewf/Themen/Energie_und_Strahlenschutz/Energie/Endbericht_Pilotprojekt_Dezentralisierung_2021_v2.pdf>`_ (`summary in English <https://energynautics.com/en/decentrality-study-for-rhineland-palatinate-completed/>`_)

* `Witteveen+Bos <https://www.witteveenbos.com/about-us/>`_, a Dutch engineering and consultancy company, used PyPSA in 2022 to consult the Ministry of Economic Affairs and Climate Policy in Netherlands: `Scenario study on nuclear energy <https://eriskgroup.com/wp-content/uploads/2022/10/Scenario-study-nuclear-energy-Conclusions-and-Summary.pdf>`_

* `Saudi Aramco <https://www.aramco.com/>`_: used PyPSA for an assessment of renewables integration in 2019, see `arXiv:1709.03761 <https://arxiv.org/abs/1709.03761>`_

* `Shell <https://www.shell.com/>`_: uses PyPSA for electricity market simulations in Europe

* `ISA <http://www.isa.co/>`_, a South American transmission company: uses PyPSA for modelling the Columbian power system in a joint research project with `EIA University <https://www.eia.edu.co/>`_ in Medellin, Columbia

* `elena international <https://www.elena-international.com/>`_: uses PyPSA for customer projects and the research cooperation `NETFLEX <https://www.zhaw.ch/en/research/research-database/project-detailview/projektid/3026/>`_

* `Edison Energy <https://www.edisonenergy.com/>`_

* `spire <https://www.spireenergy.com/>`_

* `Energy Consulting Christian Meyer <http://www.energy-consulting-meyer.de/>`_

* `ClimateXChange <https://www.climatexchange.org.uk/>`_ commissioned a report for the Scottish Government on `Electricity system security of supply in Scotland <https://www.climatexchange.org.uk/projects/electricity-system-security-of-supply-in-scotland/>`_ using PyPSA-GB.
